@@ -25,14 +25,14 @@
 #include <tqdir.h>
 #include <ktar.h>
 #include <tqdom.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <tqpixmap.h>
 #include <tqpainter.h>
 #include <kstandarddirs.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
 #include <kprogress.h>
-#include <kmainwindow.h>
+#include <tdemainwindow.h>
 
 #include "archive.h"
 #include "global.h"
@@ -99,7 +99,7 @@ void Archive::save(Basket *basket, bool withSubBaskets, const TQString &destinat
 		State::List states = (*it)->states();
 		for (State::List::iterator it2 = states.begin(); it2 != states.end(); ++it2) {
 			State *state = (*it2);
-			TQPixmap icon = kapp->iconLoader()->loadIcon(state->emblem(), KIcon::Small, 16, KIcon::DefaultState, /*path_store=*/0L, /*canReturnNull=*/true);
+			TQPixmap icon = kapp->iconLoader()->loadIcon(state->emblem(), TDEIcon::Small, 16, TDEIcon::DefaultState, /*path_store=*/0L, /*canReturnNull=*/true);
 			if (!icon.isNull()) {
 				icon.save(tempIconFile, "PNG");
 				TQString iconFileName = state->emblem().replace('/', '_');
@@ -193,7 +193,7 @@ void Archive::saveBasketToArchive(Basket *basket, bool recursive, KTar *tar, TQS
 	// Save basket icon:
 	TQString tempIconFile = tempFolder + "icon.png";
 	if (!basket->icon().isEmpty() && basket->icon() != "basket") {
-		TQPixmap icon = kapp->iconLoader()->loadIcon(basket->icon(), KIcon::Small, 16, KIcon::DefaultState, /*path_store=*/0L, /*canReturnNull=*/true);
+		TQPixmap icon = kapp->iconLoader()->loadIcon(basket->icon(), TDEIcon::Small, 16, TDEIcon::DefaultState, /*path_store=*/0L, /*canReturnNull=*/true);
 		if (!icon.isNull()) {
 			icon.save(tempIconFile, "PNG");
 			TQString iconFileName = basket->icon().replace('/', '_');
@@ -432,7 +432,7 @@ void Archive::importTagEmblems(const TQString &extractionFolder)
 				if ( (!subElement.isNull()) && subElement.tagName() == "state" ) {
 					TQString emblemName = XMLWork::getElementText(subElement, "emblem");
 					if (!emblemName.isEmpty()) {
-						TQPixmap emblem = kapp->iconLoader()->loadIcon(emblemName, KIcon::NoGroup, 16, KIcon::DefaultState, 0L, /*canReturnNull=*/true);
+						TQPixmap emblem = kapp->iconLoader()->loadIcon(emblemName, TDEIcon::NoGroup, 16, TDEIcon::DefaultState, 0L, /*canReturnNull=*/true);
 						// The icon does not exists on that computer, import it:
 						if (emblem.isNull()) {
 							// Of the emblem path was eg. "/home/seb/emblem.png", it was exported as "tag-emblems/_home_seb_emblem.png".
@@ -461,7 +461,7 @@ void Archive::importTagEmblems(const TQString &extractionFolder)
 void Archive::importArchivedBackgroundImages(const TQString &extractionFolder)
 {
 	FormatImporter copier; // Only used to copy files synchronously
-	TQString destFolder = KGlobal::dirs()->saveLocation("data", "basket/backgrounds/");
+	TQString destFolder = TDEGlobal::dirs()->saveLocation("data", "basket/backgrounds/");
 
 	TQDir dir(extractionFolder + "backgrounds/", /*nameFilder=*/"*.png", /*sortSpec=*/TQDir::Name | TQDir::IgnoreCase, /*filterSpec=*/TQDir::Files | TQDir::NoSymLinks);
 	TQStringList files = dir.entryList();
@@ -547,7 +547,7 @@ void Archive::importBasketIcon(TQDomElement properties, const TQString &extracti
 {
 	TQString iconName = XMLWork::getElementText(properties, "icon");
 	if (!iconName.isEmpty() && iconName != "basket") {
-		TQPixmap icon = kapp->iconLoader()->loadIcon(iconName, KIcon::NoGroup, 16, KIcon::DefaultState, 0L, /*canReturnNull=*/true);
+		TQPixmap icon = kapp->iconLoader()->loadIcon(iconName, TDEIcon::NoGroup, 16, TDEIcon::DefaultState, 0L, /*canReturnNull=*/true);
 		// The icon does not exists on that computer, import it:
 		if (icon.isNull()) {
 			TQDir dir;
