@@ -27,25 +27,25 @@
 #include <tqimage.h>
 #include <tqbitmap.h>
 #include <tqwhatsthis.h>
-#include <kpopupmenu.h>
+#include <tdepopupmenu.h>
 #include <tqsignalmapper.h>
 #include <tqdir.h>
 #include <kicontheme.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kstringhandler.h>
-#include <kmessagebox.h>
-#include <kfiledialog.h>
+#include <tdemessagebox.h>
+#include <tdefiledialog.h>
 #include <kprogress.h>
 #include <kstandarddirs.h>
-#include <kaboutdata.h>
-#include <kwin.h>
-#include <kaccel.h>
+#include <tdeaboutdata.h>
+#include <twin.h>
+#include <tdeaccel.h>
 #include <kpassivepopup.h>
 #include <kxmlguifactory.h>
-#include <kcmdlineargs.h>
+#include <tdecmdlineargs.h>
 #include <kglobalaccel.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kkeydialog.h>
 #include <dcopclient.h>
 #include <kdebug.h>
@@ -81,7 +81,7 @@
 const int BNPView::c_delayTooltipTime = 275;
 
 BNPView::BNPView(TQWidget *parent, const char *name, KXMLGUIClient *aGUIClient,
-				 KActionCollection *actionCollection, BasketStatusBar *bar)
+				 TDEActionCollection *actionCollection, BasketStatusBar *bar)
 	: DCOPObject("BasketIface"), TQSplitter(Qt::Horizontal, parent, name), m_actLockBasket(0), m_actPassBasket(0),
 	m_loading(true), m_newBasketPopup(false), m_firstShow(true),
 	m_regionGrabber(0), m_passiveDroppedSelection(0), m_passivePopup(0), m_actionCollection(actionCollection),
@@ -93,7 +93,7 @@ BNPView::BNPView(TQWidget *parent, const char *name, KXMLGUIClient *aGUIClient,
 	Global::bnpView = this;
 
 	// Needed when loading the baskets:
-	Global::globalAccel       = new KGlobalAccel(TQT_TQOBJECT(this)); // FIXME: might be null (KPart case)!
+	Global::globalAccel       = new TDEGlobalAccel(TQT_TQOBJECT(this)); // FIXME: might be null (KPart case)!
 	Global::backgroundManager = new BackgroundManager();
 
 	setupGlobalShortcuts();
@@ -129,7 +129,7 @@ void BNPView::lateInit()
 
 	if(instance)
 	{
-		KToolBar* toolbar = instance->richTextToolBar();
+		TDEToolBar* toolbar = instance->richTextToolBar();
 
 		if(toolbar)
 			toolbar->hide();
@@ -137,7 +137,7 @@ void BNPView::lateInit()
 */
 	if(!isPart())
 	{
-		if (Settings::useSystray() && KCmdLineArgs::parsedArgs() && KCmdLineArgs::parsedArgs()->isSet("start-hidden"))
+		if (Settings::useSystray() && TDECmdLineArgs::parsedArgs() && TDECmdLineArgs::parsedArgs()->isSet("start-hidden"))
 			if(Global::mainWindow()) Global::mainWindow()->hide();
 		else if (Settings::useSystray() && kapp->isRestored())
 			if(Global::mainWindow()) Global::mainWindow()->setShown(!Settings::startDocked());
@@ -160,7 +160,7 @@ void BNPView::lateInit()
 	DEBUG_WIN << "Baskets are loaded from " + Global::basketsFolder();
 
 	NoteDrag::createAndEmptyCuttingTmpFolder(); // If last exec hasn't done it: clean the temporary folder we will use
-	Tag::loadTags(); // Tags should be ready before loading baskets, but tags need the mainContainer to be ready to create KActions!
+	Tag::loadTags(); // Tags should be ready before loading baskets, but tags need the mainContainer to be ready to create TDEActions!
 	load();
 
 	// If no basket has been found, try to import from an older version,
@@ -205,11 +205,11 @@ void BNPView::addWelcomeBaskets()
 {
 	// Possible paths where to find the welcome basket archive, trying the translated one, and falling back to the English one:
 	TQStringList possiblePaths;
-	if (TQString(KGlobal::locale()->encoding()) == TQString("UTF-8")) { // Welcome baskets are encoded in UTF-8. If the system is not, then use the English version:
-		possiblePaths.append(KGlobal::dirs()->findResource("data", "basket/welcome/Welcome_" + KGlobal::locale()->language() + ".baskets"));
-		possiblePaths.append(KGlobal::dirs()->findResource("data", "basket/welcome/Welcome_" + TQStringList::split("_", KGlobal::locale()->language())[0] + ".baskets"));
+	if (TQString(TDEGlobal::locale()->encoding()) == TQString("UTF-8")) { // Welcome baskets are encoded in UTF-8. If the system is not, then use the English version:
+		possiblePaths.append(TDEGlobal::dirs()->findResource("data", "basket/welcome/Welcome_" + TDEGlobal::locale()->language() + ".baskets"));
+		possiblePaths.append(TDEGlobal::dirs()->findResource("data", "basket/welcome/Welcome_" + TQStringList::split("_", TDEGlobal::locale()->language())[0] + ".baskets"));
 	}
-	possiblePaths.append(KGlobal::dirs()->findResource("data", "basket/welcome/Welcome_en_US.baskets"));
+	possiblePaths.append(TDEGlobal::dirs()->findResource("data", "basket/welcome/Welcome_en_US.baskets"));
 
 	// Take the first EXISTING basket archive found:
 	TQDir dir;
@@ -265,7 +265,7 @@ void BNPView::onFirstShow()
 void BNPView::setupGlobalShortcuts()
 {
 	/* Global shortcuts */
-	KGlobalAccel *globalAccel = Global::globalAccel; // Better for the following lines
+	TDEGlobalAccel *globalAccel = Global::globalAccel; // Better for the following lines
 
 	// Ctrl+Shift+W only works when started standalone:
 	TQWidget *basketMainWindow = (TQWidget*) (Global::bnpView->parent()->inherits("MainWindow") ? Global::bnpView->parent() : 0);
@@ -372,7 +372,7 @@ void BNPView::initialize()
 	connect( m_tree, TQT_SIGNAL(pressed(TQListViewItem*)),          TQT_TQOBJECT(this), TQT_SLOT(slotPressed(TQListViewItem*)) );
 	connect( m_tree, TQT_SIGNAL(expanded(TQListViewItem*)),         TQT_TQOBJECT(this), TQT_SLOT(needSave(TQListViewItem*))    );
 	connect( m_tree, TQT_SIGNAL(collapsed(TQListViewItem*)),        TQT_TQOBJECT(this), TQT_SLOT(needSave(TQListViewItem*))    );
-	connect( m_tree, TQT_SIGNAL(contextMenu(KListView*, TQListViewItem*, const TQPoint&)),      TQT_TQOBJECT(this), TQT_SLOT(slotContextMenu(KListView*, TQListViewItem*, const TQPoint&))      );
+	connect( m_tree, TQT_SIGNAL(contextMenu(TDEListView*, TQListViewItem*, const TQPoint&)),      TQT_TQOBJECT(this), TQT_SLOT(slotContextMenu(TDEListView*, TQListViewItem*, const TQPoint&))      );
 	connect( m_tree, TQT_SIGNAL(mouseButtonPressed(int, TQListViewItem*, const TQPoint&, int)), TQT_TQOBJECT(this), TQT_SLOT(slotMouseButtonPressed(int, TQListViewItem*, const TQPoint&, int)) );
 	connect( m_tree, TQT_SIGNAL(doubleClicked(TQListViewItem*, const TQPoint&, int)), TQT_TQOBJECT(this), TQT_SLOT(slotShowProperties(TQListViewItem*, const TQPoint&, int)) );
 
@@ -409,79 +409,79 @@ void BNPView::initialize()
 
 void BNPView::setupActions()
 {
-	m_actSaveAsArchive = new KAction( i18n("&Basket Archive..."),  "baskets", 0,
+	m_actSaveAsArchive = new TDEAction( i18n("&Basket Archive..."),  "baskets", 0,
 	                                  TQT_TQOBJECT(this), TQT_SLOT(saveAsArchive()), actionCollection(), "basket_export_basket_archive" );
-	m_actOpenArchive   = new KAction( i18n("&Basket Archive..."),  "baskets", 0,
+	m_actOpenArchive   = new TDEAction( i18n("&Basket Archive..."),  "baskets", 0,
 	                                  TQT_TQOBJECT(this), TQT_SLOT(openArchive()),   actionCollection(), "basket_import_basket_archive" );
 
-	m_actHideWindow = new KAction( i18n("&Hide Window"), "", KStdAccel::shortcut(KStdAccel::Close),
+	m_actHideWindow = new TDEAction( i18n("&Hide Window"), "", TDEStdAccel::shortcut(TDEStdAccel::Close),
 								   TQT_TQOBJECT(this), TQT_SLOT(hideOnEscape()), actionCollection(), "window_hide" );
 	m_actHideWindow->setEnabled(Settings::useSystray()); // Init here !
 
-	m_actExportToHtml = new KAction( i18n("&HTML Web Page..."), "html", 0,
+	m_actExportToHtml = new TDEAction( i18n("&HTML Web Page..."), "text-html", 0,
 	             TQT_TQOBJECT(this), TQT_SLOT(exportToHTML()),      actionCollection(), "basket_export_html" );
-	new KAction( i18n("K&Notes"), "knotes", 0,
+	new TDEAction( i18n("K&Notes"), "knotes", 0,
 	             TQT_TQOBJECT(this), TQT_SLOT(importKNotes()),      actionCollection(), "basket_import_knotes" );
-	new KAction( i18n("K&Jots"), "kjots", 0,
+	new TDEAction( i18n("K&Jots"), "kjots", 0,
 	             TQT_TQOBJECT(this), TQT_SLOT(importKJots()),       actionCollection(), "basket_import_kjots" );
-	new KAction( i18n("&KnowIt..."), "knowit", 0,
+	new TDEAction( i18n("&KnowIt..."), "knowit", 0,
 	             TQT_TQOBJECT(this), TQT_SLOT(importKnowIt()),      actionCollection(), "basket_import_knowit" );
-	new KAction( i18n("Tux&Cards..."), "tuxcards", 0,
+	new TDEAction( i18n("Tux&Cards..."), "tuxcards", 0,
 	             TQT_TQOBJECT(this), TQT_SLOT(importTuxCards()),    actionCollection(), "basket_import_tuxcards" );
-	new KAction( i18n("&Sticky Notes"), "gnome", 0,
+	new TDEAction( i18n("&Sticky Notes"), "gnome", 0,
 	             TQT_TQOBJECT(this), TQT_SLOT(importStickyNotes()), actionCollection(), "basket_import_sticky_notes" );
-	new KAction( i18n("&Tomboy"), "tintin", 0,
+	new TDEAction( i18n("&Tomboy"), "tintin", 0,
 	             TQT_TQOBJECT(this), TQT_SLOT(importTomboy()),      actionCollection(), "basket_import_tomboy" );
-	new KAction( i18n("Text &File..."), "txt", 0,
+	new TDEAction( i18n("Text &File..."), "text-plain", 0,
 	             TQT_TQOBJECT(this), TQT_SLOT(importTextFile()),    actionCollection(), "basket_import_text_file" );
 
-	new KAction( i18n("&Backup && Restore..."), "", 0,
+	new TDEAction( i18n("&Backup && Restore..."), "", 0,
 	             TQT_TQOBJECT(this), TQT_SLOT(backupRestore()), actionCollection(), "basket_backup_restore" );
 
 	/** Note : ****************************************************************/
 
-	m_actDelNote  = new KAction( i18n("D&elete"), "editdelete", "Delete",
+	m_actDelNote  = new TDEAction( i18n("D&elete"), "edit-delete", "Delete",
 								 TQT_TQOBJECT(this), TQT_SLOT(delNote()), actionCollection(), "edit_delete" );
 	m_actCutNote  = KStdAction::cut(   TQT_TQOBJECT(this), TQT_SLOT(cutNote()),               actionCollection() );
 	m_actCopyNote = KStdAction::copy(  TQT_TQOBJECT(this), TQT_SLOT(copyNote()),              actionCollection() );
 
 	m_actSelectAll = KStdAction::selectAll( TQT_TQOBJECT(this), TQT_SLOT( slotSelectAll() ), actionCollection() );
 	m_actSelectAll->setStatusText( i18n( "Selects all notes" ) );
-	m_actUnselectAll = new KAction( i18n( "U&nselect All" ), "", TQT_TQOBJECT(this), TQT_SLOT( slotUnselectAll() ),
+	m_actUnselectAll = new TDEAction( i18n( "U&nselect All" ), "", TQT_TQOBJECT(this), TQT_SLOT( slotUnselectAll() ),
 									actionCollection(), "edit_unselect_all" );
 	m_actUnselectAll->setStatusText( i18n( "Unselects all selected notes" ) );
-	m_actInvertSelection = new KAction( i18n( "&Invert Selection" ), CTRL+Key_Asterisk,
+	m_actInvertSelection = new TDEAction( i18n( "&Invert Selection" ), CTRL+Key_Asterisk,
 										TQT_TQOBJECT(this), TQT_SLOT( slotInvertSelection() ),
 										actionCollection(), "edit_invert_selection" );
 	m_actInvertSelection->setStatusText( i18n( "Inverts the current selection of notes" ) );
 
-	m_actEditNote         = new KAction( i18n("Verb; not Menu", "&Edit..."), "edit",   "Return",
+	m_actEditNote         = new TDEAction( i18n("Verb; not Menu", "&Edit..."), "edit",   "Return",
 										 TQT_TQOBJECT(this), TQT_SLOT(editNote()), actionCollection(), "note_edit" );
 
 	m_actOpenNote         = KStdAction::open( TQT_TQOBJECT(this), TQT_SLOT(openNote()), actionCollection(), "note_open" );
-	m_actOpenNote->setIcon("window_new");
+	m_actOpenNote->setIcon("window-new");
 	m_actOpenNote->setText(i18n("&Open"));
 	m_actOpenNote->setShortcut("F9");
 
-	m_actOpenNoteWith     = new KAction( i18n("Open &With..."), "", "Shift+F9",
+	m_actOpenNoteWith     = new TDEAction( i18n("Open &With..."), "", "Shift+F9",
 										 TQT_TQOBJECT(this), TQT_SLOT(openNoteWith()), actionCollection(), "note_open_with" );
 	m_actSaveNoteAs       = KStdAction::saveAs( TQT_TQOBJECT(this), TQT_SLOT(saveNoteAs()), actionCollection(), "note_save_to_file" );
 	m_actSaveNoteAs->setIcon("");
 	m_actSaveNoteAs->setText(i18n("&Save to File..."));
 	m_actSaveNoteAs->setShortcut("F10");
 
-	m_actGroup        = new KAction( i18n("&Group"),          "attach",     "Ctrl+G",
+	m_actGroup        = new TDEAction( i18n("&Group"),          "attach",     "Ctrl+G",
 									 TQT_TQOBJECT(this), TQT_SLOT(noteGroup()),    actionCollection(), "note_group" );
-	m_actUngroup      = new KAction( i18n("U&ngroup"),        "",           "Ctrl+Shift+G",
+	m_actUngroup      = new TDEAction( i18n("U&ngroup"),        "",           "Ctrl+Shift+G",
 									 TQT_TQOBJECT(this), TQT_SLOT(noteUngroup()),  actionCollection(), "note_ungroup" );
 
-	m_actMoveOnTop    = new KAction( i18n("Move on &Top"),    "2uparrow",   "Ctrl+Shift+Home",
+	m_actMoveOnTop    = new TDEAction( i18n("Move on &Top"),    "2uparrow",   "Ctrl+Shift+Home",
 									 TQT_TQOBJECT(this), TQT_SLOT(moveOnTop()),    actionCollection(), "note_move_top" );
-	m_actMoveNoteUp   = new KAction( i18n("Move &Up"),        "1uparrow",   "Ctrl+Shift+Up",
+	m_actMoveNoteUp   = new TDEAction( i18n("Move &Up"),        "1uparrow",   "Ctrl+Shift+Up",
 									 TQT_TQOBJECT(this), TQT_SLOT(moveNoteUp()),   actionCollection(), "note_move_up" );
-	m_actMoveNoteDown = new KAction( i18n("Move &Down"),      "1downarrow", "Ctrl+Shift+Down",
+	m_actMoveNoteDown = new TDEAction( i18n("Move &Down"),      "1downarrow", "Ctrl+Shift+Down",
 									 TQT_TQOBJECT(this), TQT_SLOT(moveNoteDown()), actionCollection(), "note_move_down" );
-	m_actMoveOnBottom = new KAction( i18n("Move on &Bottom"), "2downarrow", "Ctrl+Shift+End",
+	m_actMoveOnBottom = new TDEAction( i18n("Move on &Bottom"), "2downarrow", "Ctrl+Shift+End",
 									 TQT_TQOBJECT(this), TQT_SLOT(moveOnBottom()), actionCollection(), "note_move_bottom" );
 #if KDE_IS_VERSION( 3, 1, 90 ) // KDE 3.2.x
 	m_actPaste = KStdAction::pasteText( TQT_TQOBJECT(this), TQT_SLOT(pasteInCurrentBasket()), actionCollection() );
@@ -496,16 +496,16 @@ void BNPView::setupActions()
 	connect( insertEmptyMapper,  TQT_SIGNAL(mapped(int)), TQT_TQOBJECT(this), TQT_SLOT(insertEmpty(int))  );
 	connect( insertWizardMapper, TQT_SIGNAL(mapped(int)), TQT_TQOBJECT(this), TQT_SLOT(insertWizard(int)) );
 
-//	m_actInsertText   = new KAction( i18n("Plai&n Text"), "text",     "Ctrl+T", actionCollection(), "insert_text"     );
-	m_actInsertHtml   = new KAction( i18n("&Text"),       "html",     "Insert", actionCollection(), "insert_html"     );
-	m_actInsertLink   = new KAction( i18n("&Link"),       "link",     "Ctrl+Y", actionCollection(), "insert_link"     );
-	m_actInsertImage  = new KAction( i18n("&Image"),      "image",    "",       actionCollection(), "insert_image"    );
-	m_actInsertColor  = new KAction( i18n("&Color"),      "colorset", "",       actionCollection(), "insert_color"    );
-	m_actInsertLauncher=new KAction( i18n("L&auncher"),   "launch",   "",       actionCollection(), "insert_launcher" );
+//	m_actInsertText   = new TDEAction( i18n("Plai&n Text"), "text",     "Ctrl+T", actionCollection(), "insert_text"     );
+	m_actInsertHtml   = new TDEAction( i18n("&Text"),       "text-html",     "Insert", actionCollection(), "insert_html"     );
+	m_actInsertLink   = new TDEAction( i18n("&Link"),       "link",     "Ctrl+Y", actionCollection(), "insert_link"     );
+	m_actInsertImage  = new TDEAction( i18n("&Image"),      "image-x-generic",    "",       actionCollection(), "insert_image"    );
+	m_actInsertColor  = new TDEAction( i18n("&Color"),      "colorset", "",       actionCollection(), "insert_color"    );
+	m_actInsertLauncher=new TDEAction( i18n("L&auncher"),   "launch",   "",       actionCollection(), "insert_launcher" );
 
-	m_actImportKMenu  = new KAction( i18n("Import Launcher from &KDE Menu..."), "kmenu",      "", actionCollection(), "insert_kmenu"     );
-	m_actImportIcon   = new KAction( i18n("Im&port Icon..."),                   "icons",      "", actionCollection(), "insert_icon"      );
-	m_actLoadFile     = new KAction( i18n("Load From &File..."),                "fileimport", "", actionCollection(), "insert_from_file" );
+	m_actImportKMenu  = new TDEAction( i18n("Import Launcher from &TDE Menu..."), "kmenu",      "", actionCollection(), "insert_kmenu"     );
+	m_actImportIcon   = new TDEAction( i18n("Im&port Icon..."),                   "icons",      "", actionCollection(), "insert_icon"      );
+	m_actLoadFile     = new TDEAction( i18n("Load From &File..."),                "fileimport", "", actionCollection(), "insert_from_file" );
 
 //	connect( m_actInsertText,     TQT_SIGNAL(activated()), insertEmptyMapper, TQT_SLOT(map()) );
 	connect( m_actInsertHtml,     TQT_SIGNAL(activated()), insertEmptyMapper, TQT_SLOT(map()) );
@@ -528,12 +528,12 @@ void BNPView::setupActions()
 	insertWizardMapper->setMapping(m_actLoadFile,     3 );
 
 	m_colorPicker = new DesktopColorPicker();
-	m_actColorPicker = new KAction( i18n("C&olor from Screen"), "kcolorchooser", "",
+	m_actColorPicker = new TDEAction( i18n("C&olor from Screen"), "kcolorchooser", "",
 									TQT_TQOBJECT(this), TQT_SLOT(slotColorFromScreen()), actionCollection(), "insert_screen_color" );
 	connect( m_colorPicker, TQT_SIGNAL(pickedColor(const TQColor&)), TQT_TQOBJECT(this), TQT_SLOT(colorPicked(const TQColor&)) );
 	connect( m_colorPicker, TQT_SIGNAL(canceledPick()),             TQT_TQOBJECT(this), TQT_SLOT(colorPickingCanceled())     );
 
-	m_actGrabScreenshot = new KAction( i18n("Grab Screen &Zone"), "ksnapshot", "",
+	m_actGrabScreenshot = new TDEAction( i18n("Grab Screen &Zone"), "ksnapshot", "",
 									   TQT_TQOBJECT(this), TQT_SLOT(grabScreenshot()), actionCollection(), "insert_screen_capture" );
 	//connect( m_actGrabScreenshot, TQT_SIGNAL(regionGrabbed(const TQPixmap&)), TQT_TQOBJECT(this), TQT_SLOT(screenshotGrabbed(const TQPixmap&)) );
 	//connect( m_colorPicker, TQT_SIGNAL(canceledPick()),             TQT_TQOBJECT(this), TQT_SLOT(colorPickingCanceled())     );
@@ -563,27 +563,27 @@ void BNPView::setupActions()
 	}
 
 	// Use the "basket" incon in Kontact so it is consistent with the Kontact "New..." icon
-	actNewBasket        = new KAction( i18n("&New Basket..."), (runInsideKontact ? "basket" : "filenew"), KStdAccel::shortcut(KStdAccel::New),
+	actNewBasket        = new TDEAction( i18n("&New Basket..."), (runInsideKontact ? "basket" : "document-new"), TDEStdAccel::shortcut(TDEStdAccel::New),
 									   TQT_TQOBJECT(this), TQT_SLOT(askNewBasket()), actionCollection(), "basket_new" );
-	actNewSubBasket     = new KAction( i18n("New &Sub-Basket..."), "", "Ctrl+Shift+N",
+	actNewSubBasket     = new TDEAction( i18n("New &Sub-Basket..."), "", "Ctrl+Shift+N",
 									   TQT_TQOBJECT(this), TQT_SLOT(askNewSubBasket()), actionCollection(), "basket_new_sub" );
-	actNewSiblingBasket = new KAction( i18n("New Si&bling Basket..."), "", "",
+	actNewSiblingBasket = new TDEAction( i18n("New Si&bling Basket..."), "", "",
 									   TQT_TQOBJECT(this), TQT_SLOT(askNewSiblingBasket()), actionCollection(), "basket_new_sibling" );
 
-	KActionMenu *newBasketMenu = new KActionMenu(i18n("&New"), "filenew", actionCollection(), "basket_new_menu");
+	TDEActionMenu *newBasketMenu = new TDEActionMenu(i18n("&New"), "document-new", actionCollection(), "basket_new_menu");
 	newBasketMenu->insert(actNewBasket);
 	newBasketMenu->insert(actNewSubBasket);
 	newBasketMenu->insert(actNewSiblingBasket);
 	connect( newBasketMenu, TQT_SIGNAL(activated()), TQT_TQOBJECT(this), TQT_SLOT(askNewBasket()) );
 
-	m_actPropBasket = new KAction( i18n("&Properties..."), "misc", "F2",
+	m_actPropBasket = new TDEAction( i18n("&Properties..."), "misc", "F2",
 								   TQT_TQOBJECT(this), TQT_SLOT(propBasket()), actionCollection(), "basket_properties" );
-	m_actDelBasket  = new KAction( i18n("Remove Basket", "&Remove"), "", 0,
+	m_actDelBasket  = new TDEAction( i18n("Remove Basket", "&Remove"), "", 0,
 								   TQT_TQOBJECT(this), TQT_SLOT(delBasket()), actionCollection(), "basket_remove" );
 #ifdef HAVE_LIBGPGME
-	m_actPassBasket = new KAction( i18n("Password protection", "Pass&word..."), "", 0,
+	m_actPassBasket = new TDEAction( i18n("Password protection", "Pass&word..."), "", 0,
 								   TQT_TQOBJECT(this), TQT_SLOT(password()), actionCollection(), "basket_password" );
-	m_actLockBasket = new KAction( i18n("Lock Basket", "&Lock"), "", "Ctrl+L",
+	m_actLockBasket = new TDEAction( i18n("Lock Basket", "&Lock"), "", "Ctrl+L",
 								   TQT_TQOBJECT(this), TQT_SLOT(lockBasket()), actionCollection(), "basket_lock" );
 #endif
 	/** Edit : ****************************************************************/
@@ -593,29 +593,29 @@ void BNPView::setupActions()
 	//m_actRedo     = KStdAction::redo(  TQT_TQOBJECT(this), TQT_SLOT(redo()),                 actionCollection() );
 	//m_actRedo->setEnabled(false); // Not yet implemented !
 
-	m_actShowFilter  = new KToggleAction( i18n("&Filter"), "filter", KStdAccel::shortcut(KStdAccel::Find),
+	m_actShowFilter  = new TDEToggleAction( i18n("&Filter"), "filter", TDEStdAccel::shortcut(TDEStdAccel::Find),
 										  actionCollection(), "edit_filter" );
 	connect( m_actShowFilter, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(showHideFilterBar(bool)) );
 
-	m_actFilterAllBaskets = new KToggleAction( i18n("Filter all &Baskets"), "find", "Ctrl+Shift+F",
+	m_actFilterAllBaskets = new TDEToggleAction( i18n("Filter all &Baskets"), "edit-find", "Ctrl+Shift+F",
 											   actionCollection(), "edit_filter_all_baskets" );
 	connect( m_actFilterAllBaskets, TQT_SIGNAL(toggled(bool)), TQT_TQOBJECT(this), TQT_SLOT(toggleFilterAllBaskets(bool)) );
 
-	m_actResetFilter = new KAction( i18n( "&Reset Filter" ), "locationbar_erase", "Ctrl+R",
+	m_actResetFilter = new TDEAction( i18n( "&Reset Filter" ), "locationbar_erase", "Ctrl+R",
 									TQT_TQOBJECT(this), TQT_SLOT( slotResetFilter() ), actionCollection(), "edit_filter_reset" );
 
 	/** Go : ******************************************************************/
 
-	m_actPreviousBasket = new KAction( i18n( "&Previous Basket" ), "up",      "Alt+Up",
+	m_actPreviousBasket = new TDEAction( i18n( "&Previous Basket" ), "go-up",   "Alt+Up",
 									   TQT_TQOBJECT(this), TQT_SLOT(goToPreviousBasket()), actionCollection(), "go_basket_previous" );
-	m_actNextBasket     = new KAction( i18n( "&Next Basket" ),     "down",    "Alt+Down",
+	m_actNextBasket     = new TDEAction( i18n( "&Next Basket" ),     "go-down", "Alt+Down",
 									   TQT_TQOBJECT(this), TQT_SLOT(goToNextBasket()),     actionCollection(), "go_basket_next"     );
-	m_actFoldBasket     = new KAction( i18n( "&Fold Basket" ),     "back",    "Alt+Left",
+	m_actFoldBasket     = new TDEAction( i18n( "&Fold Basket" ),     "back",    "Alt+Left",
 									   TQT_TQOBJECT(this), TQT_SLOT(foldBasket()),         actionCollection(), "go_basket_fold"     );
-	m_actExpandBasket   = new KAction( i18n( "&Expand Basket" ),   "forward", "Alt+Right",
+	m_actExpandBasket   = new TDEAction( i18n( "&Expand Basket" ),   "forward", "Alt+Right",
 									   TQT_TQOBJECT(this), TQT_SLOT(expandBasket()),       actionCollection(), "go_basket_expand"   );
 	// FOR_BETA_PURPOSE:
-//	m_convertTexts = new KAction( i18n("Convert text notes to rich text notes"), "compfile", "",
+//	m_convertTexts = new TDEAction( i18n("Convert text notes to rich text notes"), "compfile", "",
 //								  TQT_TQOBJECT(this), TQT_SLOT(convertTexts()), actionCollection(), "beta_convert_texts" );
 
 	InlineEditors::instance()->initToolBars(actionCollection());
@@ -626,7 +626,7 @@ void BNPView::setupActions()
 
 	/** Help : ****************************************************************/
 
-	new KAction( i18n("&Welcome Baskets"), "", "", TQT_TQOBJECT(this), TQT_SLOT(addWelcomeBaskets()), actionCollection(), "help_welcome_baskets" );
+	new TDEAction( i18n("&Welcome Baskets"), "", "", TQT_TQOBJECT(this), TQT_SLOT(addWelcomeBaskets()), actionCollection(), "help_welcome_baskets" );
 }
 
 TQListViewItem* BNPView::firstListViewItem()
@@ -647,7 +647,7 @@ void BNPView::slotMouseButtonPressed(int button, TQListViewItem *item, const TQP
 	}
 }
 
-void BNPView::slotContextMenu(KListView */*listView*/, TQListViewItem *item, const TQPoint &pos)
+void BNPView::slotContextMenu(TDEListView */*listView*/, TQListViewItem *item, const TQPoint &pos)
 {
 	TQString menuName;
 	if (item) {
@@ -764,7 +764,7 @@ void BNPView::load()
 	m_loading = false;
 }
 
-void BNPView::load(KListView */*listView*/, TQListViewItem *item, const TQDomElement &baskets)
+void BNPView::load(TDEListView */*listView*/, TQListViewItem *item, const TQDomElement &baskets)
 {
 	TQDomNode n = baskets.firstChild();
 	while ( ! n.isNull() ) {
@@ -1410,7 +1410,7 @@ void BNPView::updateNotesActions()
 	m_actMoveNoteDown    ->setEnabled( !isLocked && oneOrSeveralSelected );
 	m_actMoveOnBottom    ->setEnabled( !isLocked && oneOrSeveralSelected && !currentBasket()->isFreeLayout() );
 
-	for (KAction *action = m_insertActions.first(); action; action = m_insertActions.next())
+	for (TDEAction *action = m_insertActions.first(); action; action = m_insertActions.next())
 		action->setEnabled( !isLocked );
 
 	// From the old Note::contextMenuEvent(...) :
@@ -1429,7 +1429,7 @@ void BNPView::updateNotesActions()
 }
 } else if (m_type != Color) {
 	popupMenu->insertSeparator();
-	popupMenu->insertItem( SmallIconSet("filesaveas"), i18n("&Save a copy as..."), TQT_TQOBJECT(this), TQT_SLOT(slotSaveAs()), 0, 10 );
+	popupMenu->insertItem( SmallIconSet("document-save-as"), i18n("&Save a copy as..."), TQT_TQOBJECT(this), TQT_SLOT(slotSaveAs()), 0, 10 );
 }*/
 }
 
@@ -1533,7 +1533,7 @@ TQPopupMenu* BNPView::popupMenu(const TQString &menuName)
 	if (menu == 0) {
 		if(!hack)
 		{
-			KStandardDirs stdDirs;
+			TDEStandardDirs stdDirs;
 			KMessageBox::error( this, i18n(
 					"<p><b>The file basketui.rc seems to not exist or is too old.<br>"
 							"%1 cannot run without it and will stop.</b></p>"
@@ -1551,7 +1551,7 @@ TQPopupMenu* BNPView::popupMenu(const TQString &menuName)
 		if(!isPart())
 			exit(1); // We SHOULD exit right now and abord everything because the caller except menu != 0 to not crash.
 		else
-			menu = new KPopupMenu; // When running in kpart we cannot exit
+			menu = new TDEPopupMenu; // When running in kpart we cannot exit
 	}
 	return menu;
 }
@@ -1598,7 +1598,7 @@ void BNPView::grabScreenshot(bool global)
 	// A special case is where the action is triggered with the global keyboard shortcut.
 	// In this case, global is true, and we don't wait.
 	// In the future, if global is also defined for other cases, check for
-	// enum KAction::ActivationReason { UnknownActivation, EmulatedActivation, AccelActivation, PopupMenuActivation, ToolBarActivation };
+	// enum TDEAction::ActivationReason { UnknownActivation, EmulatedActivation, AccelActivation, PopupMenuActivation, ToolBarActivation };
 	int delay = (isMainWindowActive() ? 500 : (global/*kapp->activePopupWidget()*/ ? 0 : 200));
 
 	m_colorPickWasGlobal = global;
@@ -1710,7 +1710,7 @@ void BNPView::delBasket()
 													 .arg(Tools::textToHTMLWithoutP(basket->basketName())),
 											 i18n("Remove Basket")
 #if KDE_IS_VERSION( 3, 2, 90 ) // KDE 3.3.x
-													 , KGuiItem(i18n("&Remove Basket"), "editdelete"), KStdGuiItem::cancel());
+													 , KGuiItem(i18n("&Remove Basket"), "edit-delete"), KStdGuiItem::cancel());
 #else
 		                    );
 #endif
@@ -1726,7 +1726,7 @@ void BNPView::delBasket()
 				basketsList,
 				i18n("Remove Children Baskets")
 #if KDE_IS_VERSION( 3, 2, 90 ) // KDE 3.3.x
-						, KGuiItem(i18n("&Remove Children Baskets"), "editdelete"));
+						, KGuiItem(i18n("&Remove Children Baskets"), "edit-delete"));
 #else
 		);
 #endif
@@ -1757,7 +1757,7 @@ void BNPView::doBasketDeletion(Basket *basket)
 	basket->deleteFiles();
 	removeBasket(basket);
 	// Remove the action to avoir keyboard-shortcut clashes:
-	delete basket->m_action; // FIXME: It's quick&dirty. In the future, the Basket should be deleted, and then the KAction deleted in the Basket destructor.
+	delete basket->m_action; // FIXME: It's quick&dirty. In the future, the Basket should be deleted, and then the TDEAction deleted in the Basket destructor.
 	delete decoBasket;
 //	delete basket;
 }
@@ -1793,7 +1793,7 @@ void BNPView::saveAsArchive()
 
 	TQDir dir;
 
-	KConfig *config = KGlobal::config();
+	TDEConfig *config = TDEGlobal::config();
 	config->setGroup("Basket Archive");
 	TQString folder = config->readEntry("lastFolder", TQDir::homeDirPath()) + "/";
 	TQString url = folder + TQString(basket->basketName()).replace("/", "_") + ".baskets";
@@ -1810,7 +1810,7 @@ void BNPView::saveAsArchive()
 				"<qt>" + i18n("The file <b>%1</b> already exists. Do you really want to override it?")
 					.arg(KURL(destination).fileName()),
 				i18n("Override File?"),
-				KGuiItem(i18n("&Override"), "filesave")
+				KGuiItem(i18n("&Override"), "document-save")
 			);
 			if (result == KMessageBox::Cancel)
 				return;
@@ -1845,7 +1845,7 @@ void BNPView::openArchive()
 
 void BNPView::activatedTagShortcut()
 {
-	Tag *tag = Tag::tagForKAction((KAction*)sender());
+	Tag *tag = Tag::tagForTDEAction((TDEAction*)sender());
 	currentBasket()->activatedTagShortcut(tag);
 }
 
@@ -1957,7 +1957,7 @@ void BNPView::showPassiveDroppedDelayed()
 	m_passivePopup->setView(
 			title.arg(Tools::textToHTMLWithoutP(currentBasket()->basketName())),
 	(contentsPixmap.isNull() ? "" : "<img src=\"_passivepopup_image_\">"),
-	kapp->iconLoader()->loadIcon(currentBasket()->icon(), KIcon::NoGroup, 16, KIcon::DefaultState, 0L, true));
+	kapp->iconLoader()->loadIcon(currentBasket()->icon(), TDEIcon::NoGroup, 16, TDEIcon::DefaultState, 0L, true));
 	m_passivePopup->show();
 }
 
@@ -1970,7 +1970,7 @@ void BNPView::showPassiveImpossible(const TQString &message)
 			.arg(i18n("Basket <i>%1</i> is locked"))
 			.arg(Tools::textToHTMLWithoutP(currentBasket()->basketName())),
 	message,
-	kapp->iconLoader()->loadIcon(currentBasket()->icon(), KIcon::NoGroup, 16, KIcon::DefaultState, 0L, true));
+	kapp->iconLoader()->loadIcon(currentBasket()->icon(), TDEIcon::NoGroup, 16, TDEIcon::DefaultState, 0L, true));
 	m_passivePopup->show();
 }
 
@@ -1995,7 +1995,7 @@ void BNPView::showPassiveContent(bool forceShow/* = false*/)
 			.arg(Tools::textToHTMLWithoutP(currentBasket()->basketName()), i18n("(Locked)"))
 	: Tools::textToHTMLWithoutP(currentBasket()->basketName()) ),
 	message,
-	kapp->iconLoader()->loadIcon(currentBasket()->icon(), KIcon::NoGroup, 16, KIcon::DefaultState, 0L, true));
+	kapp->iconLoader()->loadIcon(currentBasket()->icon(), TDEIcon::NoGroup, 16, TDEIcon::DefaultState, 0L, true));
 	m_passivePopup->show();
 }
 
@@ -2009,7 +2009,7 @@ void BNPView::showPassiveLoading(Basket *basket)
 	m_passivePopup->setView(
 			Tools::textToHTMLWithoutP(basket->basketName()),
 	i18n("Loading..."),
-	kapp->iconLoader()->loadIcon(basket->icon(), KIcon::NoGroup, 16, KIcon::DefaultState, 0L, true));
+	kapp->iconLoader()->loadIcon(basket->icon(), TDEIcon::NoGroup, 16, TDEIcon::DefaultState, 0L, true));
 	m_passivePopup->show();
 }
 
@@ -2072,7 +2072,7 @@ void BNPView::setUnsavedStatus(bool isUnsaved)
 void BNPView::setActive(bool active)
 {
 //	std::cout << "Main Window Position: setActive(" << (active ? "true" : "false") << ")" << std::endl;
-	KMainWindow* win = Global::mainWindow();
+	TDEMainWindow* win = Global::mainWindow();
 	if(!win)
 		return;
 
@@ -2125,7 +2125,7 @@ bool BNPView::isPart()
 
 bool BNPView::isMainWindowActive()
 {
-	KMainWindow* main = Global::mainWindow();
+	TDEMainWindow* main = Global::mainWindow();
 	if (main && main->isActiveWindow())
 		return true;
 	return false;
@@ -2138,7 +2138,7 @@ void BNPView::newBasket()
 
 void BNPView::handleCommandLine()
 {
-	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
+	TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
 
 	/* Custom data folder */
 	TQCString customDataFolder = args->getOption("data-folder");
@@ -2155,7 +2155,7 @@ void BNPView::handleCommandLine()
 	/* Crash Handler to Mail Developers when Crashing: */
 #ifndef BASKET_USE_DRKONQI
 	if (!args->isSet("use-drkonquy"))
-		KCrash::setCrashHandler(Crash::crashHandler);
+		TDECrash::setCrashHandler(Crash::crashHandler);
 #endif
 }
 
@@ -2249,7 +2249,7 @@ void BNPView::enableActions()
 
 void BNPView::showMainWindow()
 {
-	KMainWindow *win = Global::mainWindow();
+	TDEMainWindow *win = Global::mainWindow();
 
 	if (win)
 	{
@@ -2261,7 +2261,7 @@ void BNPView::showMainWindow()
 
 void BNPView::populateTagsMenu()
 {
-	KPopupMenu *menu = (KPopupMenu*)(popupMenu("tags"));
+	TDEPopupMenu *menu = (TDEPopupMenu*)(popupMenu("tags"));
 	if (menu == 0 || currentBasket() == 0) // TODO: Display a messagebox. [menu is 0, surely because on first launch, the XMLGUI does not work!]
 		return;
 	menu->clear();
@@ -2278,7 +2278,7 @@ void BNPView::populateTagsMenu()
 //	connect( menu, TQT_SIGNAL(aboutToHide()), TQT_TQOBJECT(this), TQT_SLOT(disconnectTagsMenu()) );
 }
 
-void BNPView::populateTagsMenu(KPopupMenu &menu, Note *referenceNote)
+void BNPView::populateTagsMenu(TDEPopupMenu &menu, Note *referenceNote)
 {
 	if (currentBasket() == 0)
 		return;
@@ -2310,13 +2310,13 @@ void BNPView::populateTagsMenu(KPopupMenu &menu, Note *referenceNote)
 	}
 
 	menu.insertSeparator();
-//	menu.insertItem( /*SmallIconSet("editdelete"),*/ "&Assign new Tag...", 1 );
-	//id = menu.insertItem( SmallIconSet("editdelete"), "&Remove All", -2 );
+//	menu.insertItem( /*SmallIconSet("edit-delete"),*/ "&Assign new Tag...", 1 );
+	//id = menu.insertItem( SmallIconSet("edit-delete"), "&Remove All", -2 );
 	//if (referenceNote->states().isEmpty())
 	//	menu.setItemEnabled(id, false);
 //	menu.insertItem( SmallIconSet("configure"),  "&Customize...", 3 );
 	menu.insertItem( new IndentedMenuItem(i18n("&Assign new Tag...")),          1 );
-	menu.insertItem( new IndentedMenuItem(i18n("&Remove All"),   "editdelete"), 2 );
+	menu.insertItem( new IndentedMenuItem(i18n("&Remove All"),   "edit-delete"), 2 );
 	menu.insertItem( new IndentedMenuItem(i18n("&Customize..."), "configure"),  3 );
 
 	menu.setItemEnabled(1, enable);
