@@ -23,10 +23,10 @@
 
 #include <tqobject.h>
 
-class KConfig;
-class KAboutData;
-class KAction;
-class KActionCollection;
+class TDEConfig;
+class TDEAboutData;
+class TDEAction;
+class TDEActionCollection;
 
 class LikeBackPrivate;
 class LikeBackBar;
@@ -48,7 +48,7 @@ class LikeBackDialog;
  *
  * The LikeBack system has 5 components:
  * @li In the application: The comment dialog, where the user write a comment, select a type of comment, etc.
- * @li In the application: The KAction to plug in the Help menu. This action displays the comment dialog.
+ * @li In the application: The TDEAction to plug in the Help menu. This action displays the comment dialog.
  * @li In the application: The button-bar, that floats bellow titlebar of every windows of the application, and let the user to quickly show the comment dialog.
  *                         The button-bar can be hidden.
  * @li On the server: A PHP script that collects every comments that users send. The LikeBack object should be configured to contact that server.
@@ -64,7 +64,7 @@ class LikeBackDialog;
  *     // Comment the following line once you are sure all your windows have a name:
  *     likeBack->setWindowNamesListing(LikeBack::WarnUnnamedWindows);
  *
- *     // This line should be called early in your KMainWindow constructor because it references actionCollection().
+ *     // This line should be called early in your TDEMainWindow constructor because it references actionCollection().
  *     // It should be called before createGUI() for the action to be plugged in the Help menu:
  *     likeBack->sendACommentAction(actionCollection());
  * @endcode
@@ -75,7 +75,7 @@ class LikeBackDialog;
 class LikeBack : public TQObject
 {
   Q_OBJECT
-  TQ_OBJECT
+  
   public:
 	/**
 	 * Ids of every LikeBack buttons the button-bar can have.
@@ -118,18 +118,18 @@ class LikeBack : public TQObject
 	 *                         The button-bar display is stored by version. On a new version, your default value will take effect again.
 	 *                         This allow you to disable the button-bar once the version is stable enought to be released as final.
 	 * @param config           Set the configuration file where to store the user email address and if the button-bar should be shown.
-	 *                         By default (null), the KApplication configuration object is used.
-	 * @param aboutData        Set the KAboutData instance used to get the application name and version. By default (null), the KApplication about data object is used.
+	 *                         By default (null), the TDEApplication configuration object is used.
+	 * @param aboutData        Set the TDEAboutData instance used to get the application name and version. By default (null), the TDEApplication about data object is used.
 	 *                         The application name is only used in the first-use information message.
 	 *                         The version is used to store the button-bar visibility per version (can be shown in a development version but not in a final one...)
 	 *                         and to send with the comment, so you can filter per version and know if a comment refers the latest version of the application or not.
 	 */
-	LikeBack(Button buttons = DefaultButtons, bool showBarByDefault = false, KConfig *config = 0, const KAboutData *aboutData = 0);
+	LikeBack(Button buttons = DefaultButtons, bool showBarByDefault = false, TDEConfig *config = 0, const TDEAboutData *aboutData = 0);
 
 	/**
 	 * Destructor.
 	 * Also hide the button-bar, if it was shown.
-	 * Be careful, the KAction is deleted. Do not use it afterward, and take care to unplug it before destroying this LikeBack instance.
+	 * Be careful, the TDEAction is deleted. Do not use it afterward, and take care to unplug it before destroying this LikeBack instance.
 	 */
 	~LikeBack();
 
@@ -210,7 +210,7 @@ class LikeBack : public TQObject
 	TQ_UINT16 hostPort();
 
 	/**
-	 * Get the KAction letting user to show the comment dialog.
+	 * Get the TDEAction letting user to show the comment dialog.
 	 * You should plug it in your Help menu, just bellow the "Report a Bug" action, or replace it.
 	 * Adding the action below "Report a Bug" or replacing "Report a Bug" depends on your application and if you have a Bugzilla account.
 	 * If you do not have a Bugzilla account, LikeBack is a good way for your small application to get bug reports: remove "Report a Bug".
@@ -220,7 +220,7 @@ class LikeBack : public TQObject
 	 *       <Action name="likeback_send_a_comment" />
 	 * @endcode
 	 */
-	KAction* sendACommentAction(KActionCollection *parent = 0);
+	TDEAction* sendACommentAction(TDEActionCollection *parent = 0);
 
 	/**
 	 * @Returns The path of the currently active window. Each windows are separated with "~~".
@@ -281,7 +281,7 @@ class LikeBack : public TQObject
 	 * @param windowPath     The window path to send with the comment. If empty (the default), the current window path is took.
 	 *                       Separate window names with "~~". For instance "MainWindow~~NewFile~~FileOpen".
 	 *                       If you popup the dialog after an error occurred, you can put the error name in that field (if the window path has no sense in that context).
-	 *                       When the dialog is popuped up from the sendACommentAction() KAction, this value is "HelpMenu", because there is no way to know if the user
+	 *                       When the dialog is popuped up from the sendACommentAction() TDEAction, this value is "HelpMenu", because there is no way to know if the user
 	 *                       is commenting a thing he found/thinked about in a sub-dialog.
 	 * @param context        Not used for the moment. Will allow more fine-grained application status report.
 	 */
@@ -303,7 +303,7 @@ class LikeBack : public TQObject
 
   private slots:
 	/**
-	 * Slot triggered by the "Help -> Send a Comment to Developers" KAction.
+	 * Slot triggered by the "Help -> Send a Comment to Developers" TDEAction.
 	 * It popups the comment dialog, and set the window path to "HelpMenuAction",
 	 * because current window path has no meaning in that case.
 	 */
@@ -324,16 +324,16 @@ class LikeBack : public TQObject
 	void setUserWantsToShowBar(bool showBar);
 
 	/**
-	 * @Returns A pointer to the KAboutData used to determin the application name and version.
+	 * @Returns A pointer to the TDEAboutData used to determin the application name and version.
 	 * @See The LikeBack constructor for more information.
 	 */
-	const KAboutData *aboutData();
+	const TDEAboutData *aboutData();
 
 	/**
-	 * @Returns A pointer to the KConfig used to store user configuration (email address, if the button-bar should be shown).
+	 * @Returns A pointer to the TDEConfig used to store user configuration (email address, if the button-bar should be shown).
 	 * @See The LikeBack constructor for more information.
 	 */
-	KConfig *config();
+	TDEConfig *config();
 
 	/**
 	 * During the first comment sending, the user is invited to enter his email address for the developers to be able to contact him back.
