@@ -30,15 +30,15 @@
 #include <knuminput.h>
 #include <kcolorcombo.h>
 #include <kiconloader.h>
-#include <kconfig.h>
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 #include <tqwhatsthis.h>
 #include <tqbuttongroup.h>
 #include <tqradiobutton.h>
 #include <tqvbuttongroup.h>
-#include <kapplication.h>
-#include <kaboutdata.h>
+#include <tdeapplication.h>
+#include <tdeaboutdata.h>
 #include <kmimetype.h>
 #include <kstandarddirs.h>
 #include <kgpgme.h>
@@ -123,7 +123,7 @@ void Settings::loadConfig()
 	loadLinkLook(LinkLook::networkLinkLook, "Network Link Look", defaultNetworkLinkLook);
 	loadLinkLook(LinkLook::launcherLook,    "Launcher Look",     defaultLauncherLook   );
 
-	KConfig* config = Global::config();
+	TDEConfig* config = Global::config();
 	config->setGroup("Main window"); // TODO: Split with a "System tray icon" group !
 	setTreeOnLeft(           config->readBoolEntry("treeOnLeft",           true)  );
 	setFilterOnTop(          config->readBoolEntry("filterOnTop",          true)  );
@@ -207,7 +207,7 @@ void Settings::saveConfig()
 	saveLinkLook(LinkLook::networkLinkLook, "Network Link Look");
 	saveLinkLook(LinkLook::launcherLook,    "Launcher Look"    );
 
- KConfig* config = Global::config();
+ TDEConfig* config = Global::config();
 	config->setGroup("Main window");
 	config->writeEntry( "treeOnLeft",           treeOnLeft()           );
 	config->writeEntry( "filterOnTop",          filterOnTop()          );
@@ -272,7 +272,7 @@ void Settings::saveConfig()
 
 void Settings::loadLinkLook(LinkLook *look, const TQString &name, const LinkLook &defaultLook)
 {
- KConfig* config = Global::config();
+ TDEConfig* config = Global::config();
 	config->setGroup(name);
 
 	TQString underliningStrings[] = { "Always", "Never", "OnMouseHover", "OnMouseOutside" };
@@ -304,7 +304,7 @@ void Settings::loadLinkLook(LinkLook *look, const TQString &name, const LinkLook
 
 void Settings::saveLinkLook(LinkLook *look, const TQString &name)
 {
- KConfig* config = Global::config();
+ TDEConfig* config = Global::config();
 	config->setGroup(name);
 
 	TQString underliningStrings[] = { "Always", "Never", "OnMouseHover", "OnMouseOutside" };
@@ -355,7 +355,7 @@ void Settings::setAutoBullet(bool yes)
 /** GeneralPage */
 
 GeneralPage::GeneralPage(TQWidget * parent, const char * name)
- : KCModule(parent, name)
+ : TDECModule(parent, name)
 {
 	TQVBoxLayout *layout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
 	TQHBoxLayout *hLay;
@@ -404,7 +404,7 @@ GeneralPage::GeneralPage(TQWidget * parent, const char * name)
 	// System Tray Icon:
 	TQGroupBox *gbSys = new TQGroupBox(3, Qt::Vertical, i18n("System Tray Icon"), this);
 	layout->addWidget(gbSys);
-	TQVBoxLayout *sysLay = new TQVBoxLayout(gbSys, /*margin=*/0, KDialogBase::spacingHint());
+	TQVBoxLayout *sysLay = new TQVBoxLayout(KDialogBase::spacingHint());
 
 	// Dock in System Tray:
 	m_useSystray = new TQCheckBox(i18n("&Dock in system tray"), gbSys);
@@ -500,7 +500,7 @@ void GeneralPage::defaults()
 /** BasketsPage */
 
 BasketsPage::BasketsPage(TQWidget * parent, const char * name)
- : KCModule(parent, name)
+ : TDECModule(parent, name)
 {
 	TQVBoxLayout *layout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
 	TQHBoxLayout *hLay;
@@ -536,7 +536,7 @@ BasketsPage::BasketsPage(TQWidget * parent, const char * name)
 	m_exportTextTags = new TQCheckBox(i18n("&Export tags in texts"), widget);
 	connect( m_exportTextTags, TQT_SIGNAL(stateChanged(int)), this, TQT_SLOT(changed()) );
 
-	TQPixmap pixmapHelp(KGlobal::dirs()->findResource("data", "basket/images/tag_export_help.png"));
+	TQPixmap pixmapHelp(TDEGlobal::dirs()->findResource("data", "basket/images/tag_export_help.png"));
 	TQMimeSourceFactory::defaultFactory()->setPixmap("__resource_help_tag_export.png", pixmapHelp);
 	hLabel = new HelpLabel(
 		i18n("When does this apply?"),
@@ -550,10 +550,10 @@ BasketsPage::BasketsPage(TQWidget * parent, const char * name)
 	hLay->addWidget(hLabel);
 	hLay->addStretch();
 
-	m_groupOnInsertionLineWidget = new TQWidget(behaviorBox);
+	m_groupOnInsertionLineWidget = new TQWidget(layout->mainWidget());
 	TQHBoxLayout *hLayV = new TQHBoxLayout(m_groupOnInsertionLineWidget, /*margin=*/0, KDialogBase::spacingHint());
 	m_groupOnInsertionLine = new TQCheckBox(i18n("&Group a new note when clicking on the right of the insertion line"), m_groupOnInsertionLineWidget);
-	TQPixmap pixmap(KGlobal::dirs()->findResource("data", "basket/images/insertion_help.png"));
+	TQPixmap pixmap(TDEGlobal::dirs()->findResource("data", "basket/images/insertion_help.png"));
 	TQMimeSourceFactory::defaultFactory()->setPixmap("__resource_help_insertion_line.png", pixmap);
 	HelpLabel *helpV = new HelpLabel(
 		i18n("How to group a new note?"),
@@ -583,7 +583,7 @@ BasketsPage::BasketsPage(TQWidget * parent, const char * name)
 	m_middleAction->insertItem( i18n("Grab screen zone")              );
 	m_middleAction->insertItem( i18n("Insert color from screen")      );
 	m_middleAction->insertItem( i18n("Load note from file")           );
-	m_middleAction->insertItem( i18n("Import Launcher from KDE Menu") );
+	m_middleAction->insertItem( i18n("Import Launcher from TDE Menu") );
 	m_middleAction->insertItem( i18n("Import icon")                   );
 	TQLabel *labelM = new TQLabel(m_middleAction, i18n("&Shift+middle-click anywhere:"), widget);
 	ga->addWidget(labelM,                                          0, 0);
@@ -680,7 +680,7 @@ void BasketsPage::defaults()
 /** class NewNotesPage: */
 
 NewNotesPage::NewNotesPage(TQWidget * parent, const char * name)
- : KCModule(parent, name)
+ : TDECModule(parent, name)
 {
 	TQVBoxLayout *layout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
 	TQHBoxLayout *hLay;
@@ -788,14 +788,14 @@ void NewNotesPage::visualize()
 /** class NotesAppearancePage: */
 
 NotesAppearancePage::NotesAppearancePage(TQWidget * parent, const char * name)
- : KCModule(parent, name)
+ : TDECModule(parent, name)
 {
 	TQVBoxLayout *layout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
 	TQTabWidget *tabs = new TQTabWidget(this);
 	layout->addWidget(tabs);
 
-	m_soundLook       = new LinkLookEditWidget(this, i18n("Conference audio record"),                         "sound",       tabs);
-	m_fileLook        = new LinkLookEditWidget(this, i18n("Annual report"),                                   "document",    tabs);
+	m_soundLook       = new LinkLookEditWidget(this, i18n("Conference audio record"),                         "audio-x-generic",       tabs);
+	m_fileLook        = new LinkLookEditWidget(this, i18n("Annual report"),                                   "text-x-generic",    tabs);
 	m_localLinkLook   = new LinkLookEditWidget(this, i18n("Home folder"),                                     "folder_home", tabs);
 	m_networkLinkLook = new LinkLookEditWidget(this, "www.kde.org",             KMimeType::iconForURL("http://www.kde.org"), tabs);
 	m_launcherLook    = new LinkLookEditWidget(this, i18n("Launch %1").arg(kapp->aboutData()->programName()), "basket",      tabs);
@@ -835,7 +835,7 @@ void NotesAppearancePage::defaults()
 /** class ApplicationsPage: */
 
 ApplicationsPage::ApplicationsPage(TQWidget * parent, const char * name)
- : KCModule(parent, name)
+ : TDECModule(parent, name)
 {
 	/* Applications page */
 	TQVBoxLayout *layout = new TQVBoxLayout(this, /*margin=*/0, KDialogBase::spacingHint());
@@ -907,10 +907,10 @@ ApplicationsPage::ApplicationsPage(TQWidget * parent, const char * name)
 		i18n("<p>When opening Web links, they are opened in different applications, depending on the content of the link "
 		     "(a Web page, an image, a PDF document...), such as if they were files on your computer.</p>"
 		     "<p>Here is how to do if you want every Web addresses to be opened in your Web browser. "
-		     "It is useful if you are not using KDE (if you are using eg. GNOME, XFCE...).</p>"
+		     "It is useful if you are not using TDE (if you are using eg. GNOME, XFCE...).</p>"
 		     "<ul>"
-		     "<li>Open the KDE Control Center (if it is not available, try to type \"kcontrol\" in a command line terminal);</li>"
-		     "<li>Go to the \"KDE Components\" and then \"Components Selector\" section;</li>"
+		     "<li>Open the Trinity Control Center (if it is not available, try to type \"kcontrol\" in a command line terminal);</li>"
+		     "<li>Go to the \"TDE Components\" and then \"Components ChooserSelector\" section;</li>"
 		     "<li>Choose \"Web Browser\", check \"In the following browser:\" and enter the name of your Web browser (like \"firefox\" or \"epiphany\").</li>"
 		     "</ul>"
 		     "<p>Now, when you click <i>any</i> link that start with \"http://...\", it will be opened in your Web browser (eg. Mozilla Firefox or Epiphany or...).</p>"
@@ -925,12 +925,12 @@ ApplicationsPage::ApplicationsPage(TQWidget * parent, const char * name)
 		i18n("How to change the applications used to open files and links?"),
 		i18n("<p>Here is how to set the application to be used for each type of file. "
 		     "This also applies to Web links if you choose not to open them systematically in a Web browser (see the first help link). "
-		     "The default settings should be good enough for you, but this tip is useful if you are using GNOME, XFCE, or another environment than KDE.</p>"
+		     "The default settings should be good enough for you, but this tip is useful if you are using GNOME, XFCE, or another environment than TDE.</p>"
 		     "<p>This is an example of how to open HTML pages in your Web browser (and keep using the other applications for other addresses or files). "
 		     "Repeat these steps for each type of file you want to open in a specific application.</p>"
 		     "<ul>"
-		     "<li>Open the KDE Control Center (if it is not available, try to type \"kcontrol\" in a command line terminal);</li>"
-		     "<li>Go to the \"KDE Components\" and then \"File Associations\" section;</li>"
+		     "<li>Open the Trinity Control Center (if it is not available, try to type \"kcontrol\" in a command line terminal);</li>"
+		     "<li>Go to the \"TDE Components\" and then \"File Associations\" section;</li>"
 		     "<li>In the tree, expand \"text\" and click \"html\";</li>"
 		     "<li>In the applications list, add your Web browser as the first entry;</li>"
 		     "<li>Do the same for the type \"application -> xhtml+xml\".</li>"
